==> security-1.2.0-sources.jar: security/filters/AuthenticationServletHandler.java <==
package security.filters;

import framework.config.SecurityConfig;
import org.springframework.util.StringUtils;
import security.utils.SecurityTokenUtil;

import javax.servlet.FilterChain;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * 应用于Servlet的授权处理器
 */
public class AuthenticationServletHandler implements AuthenticationHandler {

    private final HttpServletRequest request;
    private final HttpServletResponse response;
    private final FilterChain filterChain;
    private final SecurityConfig securityConfig;

    public AuthenticationServletHandler(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain, SecurityConfig securityConfig) {
        this.request = request;
        this.response = response;
        this.filterChain = filterChain;
        this.securityConfig = securityConfig;
    }

    /**
     * get token
     *
     * @return
     */
    @Override
    public String getRequestToken() {
        return SecurityTokenUtil.getRequestToken(this.request, this.securityConfig);
    }

    /**
     * 获取请求路径
     *
     * @return
     */
    @Override
    public String getRequestPath() {
        return request.getServletPath();
    }

    /**
     * 获取请求方法
     *
     * @return
     */
    @Override
    public String getRequestMethod() {
        return request.getMethod();
    }

    /**
     * 令牌过期提醒
     *
     * @param seconds
     */
    @Override
    public void tokenExpiredReminder(int seconds) {
        String tokenExpirationReminderHeader = securityConfig.getTokenExpirationReminderHeader();
        if (StringUtils.hasText(tokenExpirationReminderHeader)) {
            response.addHeader(tokenExpirationReminderHeader, "" + seconds);
        }
    }

}

==> security-1.3.0-sources.jar: security/filters/AuthenticationServletHandler.java <==
package security.filters;

import framework.config.SecurityConfig;
import org.springframework.util.StringUtils;
import security.utils.SecurityTokenUtil;

import javax.servlet.FilterChain;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * 应用于Servlet的授权处理器
 */
public class AuthenticationServletHandler implements AuthenticationHandler {

    private final HttpServletRequest request;
    private final HttpServletResponse response;
    private final FilterChain filterChain;
    private final SecurityConfig securityConfig;

    public AuthenticationServletHandler(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain, SecurityConfig securityConfig) {
        this.request = request;
        this.response = response;
        this.filterChain = filterChain;
        this.securityConfig = securityConfig;
    }

    /**
     * get token
     *
     * @return
     */
    @Override
    public String getRequestToken() {
        return SecurityTokenUtil.getRequestToken(this.request, this.securityConfig);
    }

    /**
     * 获取请求路径
     *
     * @return
     */
    @Override
    public String getRequestPath() {
        return request.getServletPath();
    }

    /**
     * 获取请求方法
     *
     * @return
     */
    @Override
    public String getRequestMethod() {
        return request.getMethod();
    }

    /**
     * 令牌过期提醒
     *
     * @param seconds
     */
    @Override
    public void tokenExpiredReminder(int seconds) {
        String tokenExpirationReminderHeader = securityConfig.getTokenExpirationReminderHeader();
        if (StringUtils.hasText(tokenExpirationReminderHeader)) {
            response.addHeader(tokenExpirationReminderHeader, "" + seconds);
        }
    }

    /**
     * 令牌余量提醒
     *
     * @param seconds
     */
    @Override
    public void tokenBalanceOutput(int seconds) {
        String tokenBalanceOutputHeader = securityConfig.getTokenBalanceOutputHeader();
        if (StringUtils.hasText(tokenBalanceOutputHeader)) {
            response.addHeader(tokenBalanceOutputHeader, "" + seconds);
        }
    }
}
